log CLI connections at 4 from localhost; show last counter reset
authorBrendan O'Dea <bod@optus.net>
Thu, 13 Jan 2005 07:05:56 +0000 (07:05 +0000)
committerBrendan O'Dea <bod@optus.net>
Thu, 13 Jan 2005 07:05:56 +0000 (07:05 +0000)
Changes
cli.c
l2tpns.spec

diff --git a/Changes b/Changes
index a6c771c..1432656 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,4 +1,4 @@
-* Mon Jan 10 2005 Brendan O'Dea <bod@optusnet.com.au> 2.1.0
+* Thu Jan 13 2005 Brendan O'Dea <bod@optusnet.com.au> 2.1.0
 - Add IPv6 support from Jonathan McDowell (work in progress).
 - Add CHAP support from Jordan Hrycaj (work in progress).
 - Sanity check that cluster_send_session is not called from a child
@@ -12,6 +12,9 @@
 - Make "call_" prefix implict in CSTAT() macro.
 - Fix some format string problems.
 - Fix "clear counters".
+- Log "Accepted connection to CLI" at 4 when connection is from localhost
+  to reduce noise in logs.
+- Show time since last counter reset in "show counters".
 
 * Fri Dec 17 2004 Brendan O'Dea <bod@optusnet.com.au> 2.0.13
 - Better cluster master collision resolution: keep a counter of state
diff --git a/cli.c b/cli.c
index 2ff8879..3134a22 100644 (file)
--- a/cli.c
+++ b/cli.c
@@ -2,7 +2,7 @@
 // vim: sw=8 ts=8
 
 char const *cvs_name = "$Name:  $";
-char const *cvs_id_cli = "$Id: cli.c,v 1.48 2005-01-12 05:21:26 bodea Exp $";
+char const *cvs_id_cli = "$Id: cli.c,v 1.49 2005-01-13 07:05:56 bodea Exp $";
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -290,8 +290,9 @@ void cli_do(int sockfd)
        if (fork_and_close()) return;
        if (getpeername(sockfd, (struct sockaddr *)&addr, &l) == 0)
        {
-               LOG(3, 0, 0, "Accepted connection to CLI from %s\n", fmtaddr(addr.sin_addr.s_addr, 0));
                require_auth = addr.sin_addr.s_addr != inet_addr("127.0.0.1");
+               LOG(require_auth ? 3 : 4, 0, 0, "Accepted connection to CLI from %s\n",
+                       fmtaddr(addr.sin_addr.s_addr, 0));
        }
        else
                LOG(0, 0, 0, "getpeername() failed on cli socket.  Requiring authentication: %s\n", strerror(errno));
@@ -322,7 +323,9 @@ void cli_do(int sockfd)
        cli_loop(cli, sockfd);
 
        close(sockfd);
-       LOG(3, 0, 0, "Closed CLI connection from %s\n", fmtaddr(addr.sin_addr.s_addr, 0));
+       LOG(require_auth ? 3 : 4, 0, 0, "Closed CLI connection from %s\n",
+               fmtaddr(addr.sin_addr.s_addr, 0));
+
        exit(0);
 }
 
@@ -723,6 +726,10 @@ static int cmd_show_counters(struct cli_def *cli, char *command, char **argv, in
        cli_print(cli, "%-30s%u", "call_radiusretry",           GET_STAT(call_radiusretry));
        cli_print(cli, "%-30s%u", "call_random_data",           GET_STAT(call_random_data));
 #endif
+
+       cli_print(cli, "");
+       cli_print(cli, "Counters last reset %s ago", duration(time_now - GET_STAT(last_reset)));
+
        return CLI_OK;
 }
 
index 9e3a27a..e6b12de 100644 (file)
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
* Mon Jan 10 2005 Brendan O'Dea <bod@optusnet.com.au> 2.1.0-1
 - 2.1.0 release, see /usr/share/doc/l2tpns-2.1.0/Changes
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 
 %changelog
-* Mon Jan 10 2005 Brendan O'Dea <bod@optusnet.com.au> 2.1.0-1
+* Thu Jan 13 2005 Brendan O'Dea <bod@optusnet.com.au> 2.1.0-1
 - 2.1.0 release, see /usr/share/doc/l2tpns-2.1.0/Changes